(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[      6597,        221]
NotebookOptionsPosition[      5721,        187]
NotebookOutlinePosition[      6076,        203]
CellTagsIndexPosition[      6033,        200]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
This code solves the problem in Example 1 from Chapter 3 - the solution to a \
diffusion equation where at time=0 concentration is equal to 1 for all x<0 \
and concentration is 0 for all x>0 (i.e. a step function)

First let us define Greens function for this problem\
\>", "Text",
 CellChangeTimes->{{3.630347505020493*^9, 3.630347572931473*^9}}],

Cell[BoxData[
 RowBox[{"G", ":=", 
  RowBox[{
   RowBox[{"1", "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"4", "*", "Pi", "*", "d", "*", "t"}], "]"}]}], "*", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "-", "xi"}], ")"}], "^", "2"}]}], "/", 
     RowBox[{"(", 
      RowBox[{"4", "*", "d", "*", "t"}], ")"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.630347576188456*^9, 3.630347622507669*^9}}],

Cell["\<\
Note that since for this problem phi, the source term is zero, we do not need \
to worry about having (t-tau) terms in the Greens function

Now the solution to the problem is given by the integral of the initial \
condition and the Greens function

The initial condition is given by C(x,t=0)=H(-x) where H is the Heaviside \
step function.

Therefore\
\>", "Text",
 CellChangeTimes->{{3.630347645756174*^9, 3.63034775354679*^9}}],

Cell[BoxData[
 RowBox[{"C0", ":=", 
  RowBox[{"HeavisideTheta", "[", 
   RowBox[{"-", "xi"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.630347757823154*^9, 3.630347767099032*^9}, 
   3.630347818419096*^9}],

Cell["\<\
Note that we define the initial condition with xi, the Greens function \
variable, rather than x (look at the solution on slide ). The solution is now \
given by\
\>", "Text",
 CellChangeTimes->{{3.63034777838717*^9, 3.630347784498679*^9}, {
  3.6303478246111593`*^9, 3.630347872938396*^9}}],

Cell[BoxData[
 RowBox[{"Solution", ":=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"C0", "*", "G"}], ",", 
    RowBox[{"{", 
     RowBox[{"xi", ",", 
      RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.630347794139696*^9, 3.63034781465963*^9}, {
  3.630347876954858*^9, 3.6303479226183662`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["Solution"], "Input",
 CellChangeTimes->{{3.6303479247058983`*^9, 3.63034792747442*^9}}],

Cell[BoxData[
 RowBox[{"ConditionalExpression", "[", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    SqrtBox[
     FractionBox["1", 
      RowBox[{"d", " ", "t"}]]], " ", 
    SqrtBox[
     RowBox[{"d", " ", "t"}]], " ", 
    RowBox[{"Erfc", "[", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SqrtBox[
       FractionBox["1", 
        RowBox[{"d", " ", "t"}]]], " ", "x"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Re", "[", 
        FractionBox["1", 
         RowBox[{"d", " ", "t"}]], "]"}], "\[GreaterEqual]", "0"}], "&&", 
      RowBox[{
       RowBox[{"Re", "[", 
        FractionBox["x", 
         RowBox[{"d", " ", "t"}]], "]"}], ">", "0"}]}], ")"}], "||", 
    RowBox[{
     RowBox[{"Re", "[", 
      FractionBox["1", 
       RowBox[{"d", " ", "t"}]], "]"}], ">", "0"}]}]}], "]"}]], "Output",
 CellChangeTimes->{3.6303479296649446`*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does not know if d and t are real, greater than zero etc. so you have to \
simplify this expression"
}], "Text",
 CellChangeTimes->{{3.630347943050865*^9, 3.630347965978066*^9}}],

Cell[CellGroupData[{

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.6303479008665657`*^9, 3.630347917084071*^9}}],

Cell[BoxData["Concetration"], "Output",
 CellChangeTimes->{3.630347902922537*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Solution", ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"C0", "*", "G"}], ",", 
      RowBox[{"{", 
       RowBox[{"xi", ",", 
        RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}], ",", 
    " ", 
    RowBox[{
     RowBox[{"d", ">", "0"}], " ", "&&", " ", 
     RowBox[{"t", ">", "0"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.630348000277197*^9, 3.630348022418231*^9}}],

Cell[CellGroupData[{

Cell[BoxData["Solution"], "Input",
 CellChangeTimes->{{3.630348029045702*^9, 3.63034803028211*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"Erfc", "[", 
   FractionBox["x", 
    RowBox[{"2", " ", 
     SqrtBox[
      RowBox[{"d", " ", "t"}]]}]], "]"}]}]], "Output",
 CellChangeTimes->{3.630348032462557*^9}]
}, Open  ]],

Cell["\<\
You may not be familiar with the function Erfc; it is called the \
complimentary error function and is a standard function that arises when you \
integrate functions of the type exp(-x^2), or better said the error function \
erf(x) is what you get. erf(x) and erfc(x) are related to one another by \
erfc(x)=1-erf(x). See wikipeda for details \
(http://en.wikipedia.org/wiki/Error_function) . Ok, now \
let\[CloseCurlyQuote]s explore what this solution looks like - to do that \
open Chapter3-Ex1plot\
\>", "Text",
 CellChangeTimes->{{3.6303480517624493`*^9, 3.630348169409011*^9}, {
  3.630348221978837*^9, 3.630348252272812*^9}}]
},
WindowSize->{808, 911},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 357, 7, 87, "Text"],
Cell[918, 29, 468, 14, 28, "Input"],
Cell[1389, 45, 439, 12, 163, "Text"],
Cell[1831, 59, 204, 5, 28, "Input"],
Cell[2038, 66, 301, 6, 49, "Text"],
Cell[2342, 74, 359, 10, 28, "Input"],
Cell[CellGroupData[{
Cell[2726, 88, 101, 1, 28, "Input"],
Cell[2830, 91, 916, 31, 95, "Output"]
}, Open  ]],
Cell[3761, 125, 246, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[4032, 135, 94, 1, 28, "Input"],
Cell[4129, 138, 81, 1, 28, "Output"]
}, Open  ]],
Cell[4225, 142, 476, 14, 28, "Input"],
Cell[CellGroupData[{
Cell[4726, 160, 99, 1, 28, "Input"],
Cell[4828, 163, 233, 8, 52, "Output"]
}, Open  ]],
Cell[5076, 174, 641, 11, 106, "Text"]
}
]
*)

(* End of internal cache information *)
